# C
function python_executable_path end
function python_library_handle end
function python_library_path end
function python_version end

# Core
function getptr end
function ispy end
function pyabs end
function pyadd end
function pyall end
function pyand end
function pyany end
function pyascii end
function pybool end
function pybytes end
function pycall end
function pycallable end
function pycollist end
function pycompile end
function pycomplex end
function pycontains end
function pycopy! end
function pydate end
function pydatetime end
function pydel! end
function pydelattr end
function pydelitem end
function pydict end
function pydir end
function pydivmod end
function pyeq end
function pyeval end
function pyexec end
function pyfloat end
function pyfloordiv end
function pyfraction end
function pyfrozenset end
function pyge end
function pygetattr end
function pygetitem end
function pygt end
function pyhasattr end
function pyhash end
function pyhasitem end
function pyhelp end
function pyiadd end
function pyiand end
function pyifloordiv end
function pyilshift end
function pyimatmul end
function pyimod end
function pyimport end
function pyimul end
function pyin end
function pyindex end
function pyint end
function pyinv end
function pyior end
function pyipow end
function pyirshift end
function pyis end
function pyisinstance end
function pyisnull end
function pyissubclass end
function pyisub end
function pyiter end
function pyitruediv end
function pyixor end
function pyle end
function pylen end
function pylist end
function pylshift end
function pylt end
function pymatmul end
function pymod end
function pymul end
function pyne end
function pyneg end
function pynew end
function pynext end
function pynot end
function pyor end
function pypos end
function pypow end
function pyprint end
function pyrange end
function pyrepr end
function pyrowlist end
function pyrshift end
function pyset end
function pysetattr end
function pysetitem end
function pyslice end
function pystr end
function pysub end
function pytime end
function pytruediv end
function pytruth end
function pytuple end
function pytype end
function pywith end
function pyxor end
function unsafe_pynext end

# Convert
function pyconvert end
function pyconvert_add_rule end
function pyconvert_return end
function pyconvert_unconverted end

# JlWrap
function pybinaryio end
function pyclassmethod end
function pyfunc end
function pyisjl end
function pyjl end
function pyjlraw end
function pyjltype end
function pyjlvalue end
function pyproperty end
function pystaticmethod end
function pytextio end

# Compat
function event_loop_off end
function event_loop_on end
function fix_qt_plugin_path end
function pytable end
